A one-row tibble::tibble with the following
columns:
alphathe value of alpha passed to this function
n_samplethe number of observations in the sample for which
equivalency is being checked. This is either the value n_sample
passed to this function or the length of the vector data_sample.
mean_samplethe mean of the observations in the sample for
which equivalency is being checked. This is either the value
mean_sample passed to this function or the mean of the vector
data-sample.
sd_samplethe standard deviation of the observations in the
sample for which equivalency is being checked. This is either the value
mean_sample passed to this function or the standard deviation of
the vector data-sample.
n_qualthe number of observations in the qualification data
to which the sample is being compared for equivalency. This is either
the value n_qual passed to this function or the length of the
vector data_qual.
mean_qualthe mean of the qualification data to which the
sample is being compared for equivalency. This is either the value
mean_qual passed to this function or the mean of the vector
data_qual.
sd_qualthe standard deviation of the qualification data to
which the sample is being compared for equivalency. This is either the
value mean_qual passed to this function or the standard deviation
of the vector data_qual.
modcvlogical value indicating whether the equivalency
calculations were performed using the modified CV approach
spthe value of the pooled standard deviation. If
modecv = TRUE, this pooled standard deviation includes the
modification to the qualification CV.
t0the test statistic
t_reqthe t-value for \(\alpha / 2\) and
\(df = n1 + n2 -2\)
threshold_minthe minimum value of the sample mean that would
result in a pass
threshold_maxthe maximum value of the sample mean that would
result in a pass
resulta character vector of either "PASS" or "FAIL"
indicating the result of the test for change in mean